*************************
stellarphot Documentation
*************************

This is the documentation for stellarphot.

Reference/API
=============

.. automodapi:: stellarphot
.. automodapi:: stellarphot.photometry
.. automodapi:: stellarphot.differential_photometry
.. automodapi:: stellarphot.visualization
.. automodapi:: stellarphot.io
